==> zio-aws-s3_2.12-5.19.7.5-sources.jar: zio/aws/s3/model/ListBucketMetricsConfigurationsRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{AccountId, Token, BucketName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListBucketMetricsConfigurationsRequest(
    bucket: BucketName,
    continuationToken: Optional[Token] = Optional.Absent,
    expectedBucketOwner: Optional[AccountId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest = {
    import ListBucketMetricsConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        continuationToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.continuationToken)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly =
    zio.aws.s3.model.ListBucketMetricsConfigurationsRequest
      .wrap(buildAwsValue())
}
object ListBucketMetricsConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ListBucketMetricsConfigurationsRequest =
      zio.aws.s3.model.ListBucketMetricsConfigurationsRequest(
        bucket,
        continuationToken.map(value => value),
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def continuationToken: Optional[Token]
    def expectedBucketOwner: Optional[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getContinuationToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("continuationToken", continuationToken)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ) extends zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val continuationToken: Optional[Token] = zio.aws.core.internal
      .optionalFromNullable(impl.continuationToken())
      .map(value => zio.aws.s3.model.primitives.Token(value))
    override val expectedBucketOwner: Optional[AccountId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.expectedBucketOwner())
        .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ): zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/ListBucketMetricsConfigurationsRequest.scala <==
package zio.aws.s3.model
import zio.aws.s3.model.primitives.{AccountId, Token, BucketName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListBucketMetricsConfigurationsRequest(
    bucket: BucketName,
    continuationToken: Option[Token] = None,
    expectedBucketOwner: Option[AccountId] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest = {
    import ListBucketMetricsConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
      .builder()
      .bucket(BucketName.unwrap(bucket): java.lang.String)
      .optionallyWith(
        continuationToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.continuationToken)
      .optionallyWith(
        expectedBucketOwner.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly
      : zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly =
    zio.aws.s3.model.ListBucketMetricsConfigurationsRequest
      .wrap(buildAwsValue())
}
object ListBucketMetricsConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ListBucketMetricsConfigurationsRequest =
      zio.aws.s3.model.ListBucketMetricsConfigurationsRequest(
        bucket,
        continuationToken.map(value => value),
        expectedBucketOwner.map(value => value)
      )
    def bucket: BucketName
    def continuationToken: Option[Token]
    def expectedBucketOwner: Option[AccountId]
    def getBucket: ZIO[Any, Nothing, BucketName] = ZIO.succeed(bucket)
    def getContinuationToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("continuationToken", continuationToken)
    def getExpectedBucketOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ) extends zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly {
    override val bucket: BucketName =
      zio.aws.s3.model.primitives.BucketName(impl.bucket())
    override val continuationToken: Option[Token] = scala
      .Option(impl.continuationToken())
      .map(value => zio.aws.s3.model.primitives.Token(value))
    override val expectedBucketOwner: Option[AccountId] = scala
      .Option(impl.expectedBucketOwner())
      .map(value => zio.aws.s3.model.primitives.AccountId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ListBucketMetricsConfigurationsRequest
  ): zio.aws.s3.model.ListBucketMetricsConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}
